==> ajaxplorer-4.2.3.tbz: www/ajaxplorer/plugins/index.lucene/resources/i18n/conf/en.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
$mess=array(
"Lucene Search Engine" => "Lucene Search Engine",
"Zend_Search_Lucene implementation to index all files and search a whole repository quickly." => "Zend_Search_Lucene implementation to index all files and search a whole repository quickly.",
"Index Content" => "Index Content",
"Parses the file when possible and index its content (see plugin global options)" => "Parses the file when possible and index its content (see plugin global options)",
"Index Meta Fields" => "Index Meta Fields",
"Which additionnal fields to index and search" => "Which additionnal fields to index and search",
"Repository keywords" => "Repository keywords",
"If your repository path is defined dynamically by specific keywords like AJXP_USER, or your own, mention them here." => "If your repository path is defined dynamically by specific keywords like AJXP_USER, or your own, mention them here.",
"Parse Content Until" => "Parse Content Until",
"Skip content parsing and indexation for files bigger than this size (must be in Bytes)" => "Skip content parsing and indexation for files bigger than this size (must be in Bytes)",
"HTML files" => "HTML files",
"List of extensions to consider as HTML file and parse content" => "List of extensions to consider as HTML file and parse content",
"Text files" => "Text files",
"List of extensions to consider as Text file and parse content" => "List of extensions to consider as Text file and parse content",
);
?>

==> ajaxplorer-5.0.1.tbz: www/ajaxplorer/plugins/index.lucene/resources/i18n/conf/en.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
$mess=array(
"Lucene Search Engine" => "Lucene Search Engine",
"Zend_Search_Lucene implementation to index all files and search a whole repository quickly." => "Zend_Search_Lucene implementation to index all files and search a whole workspace quickly.",
"Index Content" => "Index Content",
"Parses the file when possible and index its content (see plugin global options)" => "Parses the file when possible and index its content (see plugin global options)",
"Index Meta Fields" => "Index Meta Fields",
"Which additionnal fields to index and search" => "Which additionnal fields to index and search",
"Repository keywords" => "Repository keywords",
"If your repository path is defined dynamically by specific keywords like AJXP_USER, or your own, mention them here." => "If your workspace path is defined dynamically by specific keywords like AJXP_USER, or your own, mention them here.",
"Parse Content Until" => "Parse Content Until",
"Skip content parsing and indexation for files bigger than this size (must be in Bytes)" => "Skip content parsing and indexation for files bigger than this size (must be in Bytes)",
"HTML files" => "HTML files",
"List of extensions to consider as HTML file and parse content" => "List of extensions to consider as HTML file and parse content",
"Text files" => "Text files",
"List of extensions to consider as Text file and parse content" => "List of extensions to consider as Text file and parse content",
);
?>
